@@ -5,6 +5,7 @@
 #' @param x.sens string with the name for the x axis.
 #' @param y.sens string with the name for the y axis of the sensitivity functions (when \code{type = 6}).
 #' @param y.ind string with the name for the y axis of the parameter importance indices.
+#' @param bar.colors any valid specification of a color.
 #' @param label.size a number to specify the size of axes labels and text.
 #' @param x.axis.angle a number with angle of rotation for x axis text. Passed to \code{angle} argument of \code{\link{element_text}}. 
 #' @details Font size of saved plots is usually different to the font size seen in graphic browsers. Before changing font sizes, see the final result in saved (or preview) plots.
@@ -12,39 +13,35 @@
 #' 
 #' Soetaert K, Cash J and Mazzia F (2012). Solving differential equations in R. Springer.
 #' 
+#' Baquero, O. S., Marconcin, S., Rocha, A., & Garcia, R. D. C. M. (2018). Companion animal demography and population management in Pinhais, Brazil. Preventive Veterinary Medicine.
+#' 
 #' \url{http://oswaldosantos.github.io/capm}
 #' @seealso \link[FME]{plot.sensFun}.
 #' @export
 #' @examples
-#' ## IASA model
-#' 
+#' ## IASA model#' 
+
 #' ## Parameters and intial conditions.
-#' pars_solve_iasa = c(
-#'    b1 = 21871, b2 = 4374,
-#'    df1 = 0.104, dm1 = 0.098, df2 = 0.125, dm2 = 0.118,
-#'    sf1 = 0.069, sf2 = 0.05, sm1 = 0.028, sm2 = 0.05,
-#'    k1 = 98050, k2 = 8055, h1 = 1, h2 = 0.5,
-#'    a = 0.054, alpha = 0.1, v = 0.2, z = 0.1)
-#'    
-#' init_solve_iasa = c(
-#'    f1 = 33425, fs1 = 10865,
-#'    m1 = 38039, ms1 = 6808,
-#'    f2 = 3343, fs2 = 109,
-#'    m2 = 3804, ms2 = 68)
-#'    
-#' 
+#' data(dogs)
+#' dogs_iasa <- GetDataIASA(dogs,
+#'                         destination.label = "Pinhais",
+#'                         total.estimate = 50444)#' 
+
 #' # Solve for point estimates.
-#' solve_iasa_pt <- SolveIASA(pars = pars_solve_iasa, 
-#'                           init = init_solve_iasa, 
-#'                           time = 0:15, method = 'rk4')
-#' 
+#' solve_iasa_pt <- SolveIASA(pars = dogs_iasa$pars,
+#'                          init = dogs_iasa$init,
+#'                          time = 0:15,
+#'                          alpha.owned = TRUE,
+#'                          method = 'rk4')#' 
+
 #' ## Calculate local sensitivities to all parameters.
-#' local_solve_iasa2 <- CalculateLocalSens(model.out = solve_iasa_pt,
-#'                                         sensv = "n2")
-#' 
+#' local_solve_iasa2 <- CalculateLocalSens(
+#'  model.out = solve_iasa_pt, sensv = "n2")#' 
+
 #' ## Plot local sensitivities
-#' PlotLocalSens(local_solve_iasa2)
-PlotLocalSens <- function (local.out = NULL, x.sens = "Time", y.sens = "Sensitivity", y.ind = c("L1", "L2", "Mean", "Min", "Max"), label.size = 10, x.axis.angle = 90, type = 1) {
+#' PlotLocalSens(local_solve_iasa2)#' 
+#' 
+PlotLocalSens <- function (local.out = NULL, x.sens = "Time", y.sens = "Sensitivity", y.ind = c("L1", "L2", "Mean", "Min", "Max"), bar.colors = "DarkRed", label.size = 10, x.axis.angle = 90, type = 1) {
   if (length(y.ind) != 5) {
     stop("The length of y.ind must be equal to 5.")
   }
@@ -53,15 +50,14 @@ PlotLocalSens <- function (local.out = NULL, x.sens = "Time", y.sens = "Sensitiv
   vplayout <- function(x, y) {
     viewport(layout.pos.row = x, layout.pos.col = y)
   }
-  tmp <- melt(local.out[, -2], id.vars = "x")
+  tmp <- gather(local.out[, -2], variable, value, -x)
   loc <- ggplot(tmp, aes(x = x, y = value, colour = variable)) + 
     geom_line(size = 0.5) + theme(legend.position = "none") + 
     xlab(x.sens) + ylab(y.sens)
   ordered.summary <- summary(local.out)[
     order(summary(local.out)[, "L1"], decreasing = T), ]
   tmp1 <- cbind(w = factor(rownames(ordered.summary),
-                           levels = (rownames(ordered.summary))),
-                ordered.summary)
+                           levels = (rownames(ordered.summary))), ordered.summary)
   coln <- colnames(summary(local.out))[-c(1:2, 8)]
   x.axis.lab <- as.character(tmp1$w)
   x.axis.lab[which(x.axis.lab =='a')] <- 'a'
@@ -69,9 +65,11 @@ PlotLocalSens <- function (local.out = NULL, x.sens = "Time", y.sens = "Sensitiv
   x.axis.lab[which(x.axis.lab =='alpha')] <- expression(alpha)
   for (i in 1:length(coln)) {
     assign(paste0("loc", i),
-           ggplot(tmp1, aes_string(x = "w", y = coln[i],
-                                   fill = "w", colour = "w")) +
-             geom_bar(stat = "identity") + 
+           ggplot(tmp1, aes_string(x = "w", y = coln[i])) +
+             geom_bar(stat = "identity",
+                      fill = bar.colors,
+                      colour = bar.colors) +
+             theme_minimal() + 
              theme(legend.position = "none", 
                    axis.title.x = element_blank(), 
                    axis.text.x = element_text(size = label.size - 1, 
@@ -79,7 +77,7 @@ PlotLocalSens <- function (local.out = NULL, x.sens = "Time", y.sens = "Sensitiv
                    axis.title.y = element_text(size = label.size + 2),
                    axis.text.y = element_text(size = label.size)) + 
              ylab(y.ind[i]) +
-             scale_x_discrete(labels = x.axis.lab)) 
+             scale_x_discrete(labels = x.axis.lab))
   }
   if (type == 6) {
     options(warn = -1)
